pub struct OklabScaler { /* private fields */ }Available on crate feature
colorspaces only.Expand description
Converts image to Oklab components scales it and convert back
Implementations
Sourceimpl OklabScaler
impl OklabScaler
Sourcepub fn new(
filter: ResamplingFunction,
transfer_function: TransferFunction,
) -> Self
pub fn new( filter: ResamplingFunction, transfer_function: TransferFunction, ) -> Self
Arguments
transfer_function- Transfer function to move into linear colorspace and back
Sourceimpl OklabScaler
impl OklabScaler
pub fn set_threading_policy( &mut self, threading_policy: ThreadingPolicy, ) -> Self
pub fn plan_rgb_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 3>>, PicScaleError>
pub fn plan_rgba_resampling( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, ) -> Result<Arc<Resampling<u8, 4>>, PicScaleError>