PlanarS16ImageStore

Type Alias PlanarS16ImageStore 

pub type PlanarS16ImageStore<'a> = ImageStore<'a, i16, 1>;

Aliased Type

pub struct PlanarS16ImageStore<'a> {
    pub buffer: Cow<'a, [i16]>,
    pub channels: usize,
    pub width: usize,
    pub height: usize,
    pub stride: usize,
    pub bit_depth: usize,
}

Fields

buffer: Cow<'a, [i16]>channels: usize

Channels in the image

width: usize

Image width

height: usize

Image height

stride: usize

Image stride, if stride is zero then it considered to be width * N

bit_depth: usize

This is private field, currently used only for u16, will be automatically passed from upper func