LinearScaler

Struct LinearScaler 

pub struct LinearScaler { /* private fields */ }
Converts image to linear f32 components scales it and convert back.

This is more precise and slower than scaling in linear fixed point.

This is an expensive method, and its precision might not be required, consider to use [LinearApproxScaler] instead

Implementations

Source

impl LinearScaler

pub fn new(filter: ResamplingFunction) -> Self

Available on crate feature colorspaces only.

Creates new instance with sRGB transfer function

pub fn new_with_transfer( filter: ResamplingFunction, transfer_function: TransferFunction, ) -> Self

Available on crate feature colorspaces only.

Creates new instance with requested transfer function

Source

impl LinearScaler

pub fn set_threading_policy( &mut self, threading_policy: ThreadingPolicy, ) -> Self

Available on crate feature colorspaces only.
pub fn plan_planar_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 1>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_cbcr_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 2>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_gray_alpha_resampling( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, ) -> Result<Arc<Resampling<u8, 2>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_rgb_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 3>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_rgba_resampling( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, ) -> Result<Arc<Resampling<u8, 4>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_planar_resampling16( &self, source_size: ImageSize, target_size: ImageSize, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 1>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_gray_alpha_resampling16( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 2>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_cbcr_resampling16( &self, source_size: ImageSize, target_size: ImageSize, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 2>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_rgb_resampling16( &self, source_size: ImageSize, target_size: ImageSize, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 3>>, PicScaleError>

Available on crate feature colorspaces only.
pub fn plan_rgba_resampling16( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 4>>, PicScaleError>

Available on crate feature colorspaces only.