pub struct LinearScaler { /* private fields */ }Expand description
Converts image to linear f32 components scales it and convert back.
This is more precise and slower than scaling in linear fixed point.
This is an expensive method, and its precision might not be required, consider to use [LinearApproxScaler] instead
Implementations
Sourceimpl LinearScaler
impl LinearScaler
Sourcepub fn new(filter: ResamplingFunction) -> Self
Available on crate feature colorspaces only.
pub fn new(filter: ResamplingFunction) -> Self
colorspaces only.Creates new instance with sRGB transfer function
Sourcepub fn new_with_transfer(
filter: ResamplingFunction,
transfer_function: TransferFunction,
) -> Self
Available on crate feature colorspaces only.
pub fn new_with_transfer( filter: ResamplingFunction, transfer_function: TransferFunction, ) -> Self
colorspaces only.Creates new instance with requested transfer function
Sourceimpl LinearScaler
impl LinearScaler
pub fn set_threading_policy( &mut self, threading_policy: ThreadingPolicy, ) -> Self
Available on crate feature
colorspaces only.pub fn plan_planar_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 1>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_cbcr_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 2>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_gray_alpha_resampling( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, ) -> Result<Arc<Resampling<u8, 2>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_rgb_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 3>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_rgba_resampling( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, ) -> Result<Arc<Resampling<u8, 4>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_planar_resampling16( &self, source_size: ImageSize, target_size: ImageSize, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 1>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_gray_alpha_resampling16( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 2>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_cbcr_resampling16( &self, source_size: ImageSize, target_size: ImageSize, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 2>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_rgb_resampling16( &self, source_size: ImageSize, target_size: ImageSize, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 3>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_rgba_resampling16( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, bit_depth: usize, ) -> Result<Arc<Resampling<u16, 4>>, PicScaleError>
Available on crate feature
colorspaces only.Trait Implementations
Sourceimpl Clone for LinearScaler
Available on crate feature colorspaces only.
impl Clone for LinearScaler
Available on crate feature
colorspaces only.Sourcefn clone(&self) -> LinearScaler
fn clone(&self) -> LinearScaler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinearScaler
Available on crate feature colorspaces only.
impl Debug for LinearScaler
Available on crate feature
colorspaces only.impl Copy for LinearScaler
Available on crate feature
colorspaces only.Auto Trait Implementations
impl Freeze for LinearScaler
impl RefUnwindSafe for LinearScaler
impl Send for LinearScaler
impl Sync for LinearScaler
impl Unpin for LinearScaler
impl UnsafeUnpin for LinearScaler
impl UnwindSafe for LinearScaler