pub struct OklabScaler { /* private fields */ }Expand description
Converts image to Oklab components scales it and convert back
Implementations
Sourceimpl OklabScaler
impl OklabScaler
Sourcepub fn new(
filter: ResamplingFunction,
transfer_function: TransferFunction,
) -> Self
Available on crate feature colorspaces only.
pub fn new( filter: ResamplingFunction, transfer_function: TransferFunction, ) -> Self
colorspaces only.Arguments
transfer_function- Transfer function to move into linear colorspace and back
Sourceimpl OklabScaler
impl OklabScaler
pub fn set_threading_policy( &mut self, threading_policy: ThreadingPolicy, ) -> Self
Available on crate feature
colorspaces only.pub fn plan_rgb_resampling( &self, source_size: ImageSize, target_size: ImageSize, ) -> Result<Arc<Resampling<u8, 3>>, PicScaleError>
Available on crate feature
colorspaces only.pub fn plan_rgba_resampling( &self, source_size: ImageSize, target_size: ImageSize, premultiply_alpha: bool, ) -> Result<Arc<Resampling<u8, 4>>, PicScaleError>
Available on crate feature
colorspaces only.Trait Implementations
Sourceimpl Clone for OklabScaler
Available on crate feature colorspaces only.
impl Clone for OklabScaler
Available on crate feature
colorspaces only.Sourcefn clone(&self) -> OklabScaler
fn clone(&self) -> OklabScaler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OklabScaler
Available on crate feature colorspaces only.
impl Debug for OklabScaler
Available on crate feature
colorspaces only.impl Copy for OklabScaler
Available on crate feature
colorspaces only.Auto Trait Implementations
impl Freeze for OklabScaler
impl RefUnwindSafe for OklabScaler
impl Send for OklabScaler
impl Sync for OklabScaler
impl Unpin for OklabScaler
impl UnsafeUnpin for OklabScaler
impl UnwindSafe for OklabScaler